==> sources_drippyloadingscreen_fabric_3.0.12_MC_1.19.2.jar: de/keksuccino/drippyloadingscreen/customization/elements/vanillabar/VanillaBarElement.java <==
package de.keksuccino.drippyloadingscreen.customization.elements.vanillabar;

import com.mojang.blaze3d.systems.RenderSystem;
import de.keksuccino.drippyloadingscreen.mixin.mixins.common.client.IMixinLoadingOverlay;
import de.keksuccino.fancymenu.customization.element.AbstractElement;
import de.keksuccino.fancymenu.customization.element.ElementBuilder;
import de.keksuccino.fancymenu.util.rendering.DrawableColor;
import de.keksuccino.fancymenu.util.rendering.RenderingUtils;
import de.keksuccino.fancymenu.util.rendering.gui.GuiGraphics;
import net.minecraft.class_310;
import net.minecraft.class_3532;
import net.minecraft.class_425;
import org.jetbrains.annotations.NotNull;

public class VanillaBarElement extends AbstractElement {

    @NotNull
    public DrawableColor color = DrawableColor.WHITE;

    public VanillaBarElement(@NotNull ElementBuilder<?, ?> builder) {
        super(builder);
    }

    @Override
    public void render(@NotNull GuiGraphics graphics, int mouseX, int mouseY, float partial) {

        int x = this.getAbsoluteX();
        int y = this.getAbsoluteY();
        int w = this.getAbsoluteWidth();
        int h = this.getAbsoluteHeight();
        float currentProgress = 0.5F;
        if (class_310.method_1551().method_18506() instanceof class_425) {
            currentProgress = ((IMixinLoadingOverlay)class_310.method_1551().method_18506()).getCurrentProgressDrippy();
        }

        RenderSystem.enableBlend();
        RenderingUtils.resetShaderColor(graphics);
        this.drawProgressBar(graphics, x, y, x + w, y + h, currentProgress);
        RenderingUtils.resetShaderColor(graphics);

    }

    protected void drawProgressBar(GuiGraphics graphics, int xMin, int yMin, int xMax, int yMax, float currentProgress) {
        int i = class_3532.method_15386((float)(xMax - xMin - 2) * currentProgress);
        int k = RenderingUtils.replaceAlphaInColor(this.color.getColorInt(), this.opacity);
        graphics.fill(xMin + 2, yMin + 2, xMin + i, yMax - 2, k);
        graphics.fill(xMin + 1, yMin, xMax - 1, yMin + 1, k);
        graphics.fill(xMin + 1, yMax, xMax - 1, yMax - 1, k);
        graphics.fill(xMin, yMin, xMin + 1, yMax, k);
        graphics.fill(xMax, yMin, xMax - 1, yMax, k);
    }

}

==> sources_drippyloadingscreen_fabric_3.0.16_MC_1.21.10.jar: de/keksuccino/drippyloadingscreen/customization/elements/vanillabar/VanillaBarElement.java <==
package de.keksuccino.drippyloadingscreen.customization.elements.vanillabar;

import com.mojang.blaze3d.systems.RenderSystem;
import de.keksuccino.drippyloadingscreen.mixin.mixins.common.client.IMixinLoadingOverlay;
import de.keksuccino.fancymenu.customization.element.AbstractElement;
import de.keksuccino.fancymenu.customization.element.ElementBuilder;
import de.keksuccino.fancymenu.util.rendering.DrawableColor;
import de.keksuccino.fancymenu.util.rendering.RenderingUtils;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_3532;
import net.minecraft.class_425;
import org.jetbrains.annotations.NotNull;

public class VanillaBarElement extends AbstractElement {

    @NotNull
    public DrawableColor color = DrawableColor.WHITE;

    public VanillaBarElement(@NotNull ElementBuilder<?, ?> builder) {
        super(builder);
    }

    @Override
    public void method_25394(@NotNull class_332 graphics, int mouseX, int mouseY, float partial) {

        int x = this.getAbsoluteX();
        int y = this.getAbsoluteY();
        int w = this.getAbsoluteWidth();
        int h = this.getAbsoluteHeight();
        float currentProgress = 0.5F;
        if (class_310.method_1551().method_18506() instanceof class_425) {
            currentProgress = ((IMixinLoadingOverlay)class_310.method_1551().method_18506()).getCurrentProgressDrippy();
        }

        this.drawProgressBar(graphics, x, y, x + w, y + h, currentProgress);

    }

    protected void drawProgressBar(class_332 graphics, int xMin, int yMin, int xMax, int yMax, float currentProgress) {
        int i = class_3532.method_15386((float)(xMax - xMin - 2) * currentProgress);
        int k = RenderingUtils.replaceAlphaInColor(this.color.getColorInt(), this.opacity);
        graphics.method_25294(xMin + 2, yMin + 2, xMin + i, yMax - 2, k);
        graphics.method_25294(xMin + 1, yMin, xMax - 1, yMin + 1, k);
        graphics.method_25294(xMin + 1, yMax, xMax - 1, yMax - 1, k);
        graphics.method_25294(xMin, yMin, xMin + 1, yMax, k);
        graphics.method_25294(xMax, yMin, xMax - 1, yMax, k);
    }

}
